.. _user:

##########################
Developer Reference Manual
##########################

:Release: |version|
:Date: |today|

This is the developer reference guide for ADAM which covers most of the
available functions, modules, and classes.

============================
:mod:`io` Module
============================

Module containing functions to load and preprocess radar data for inference.

.. automodule:: adam.io
    :members:
    :undoc-members:
    :show-inheritance:

=======================
:mod:`model` Module
=======================

Main module for inference.

.. automodule:: adam.model
    :members:
    :undoc-members:
    :show-inheritance:

=================
:mod:`vis` Module
=================

Main module for visualization.

.. automodule:: adam.vis
    :members:
    :undoc-members:
    :show-inheritance:

========================
:mod:`triggering` Module
========================

Main module for triggering lidar scans.

.. automodule:: adam.triggering
    :members:
    :undoc-members:
    :show-inheritance:

========================
:mod:`testing` Module
========================

Main module for testing.

.. automodule:: adam.triggering
    :members:
    :undoc-members:
    :show-inheritance:
   
==================
:mod:`util` Module
==================

Module with various utilities.

.. automodule:: adam.util
    :members:
    :undoc-members:
    :show-inheritance: